<?php

namespace Drupal\service_injector\Constant;

/**
 * Contains all string constants relating to Drupal Core services.
 *
 * Each constant is a direct match to its designated service ID. A class
 * reference is provided in the constant's docblock comment to allow quick
 * access to its service's class.
 *
 * Note that line comments are in use only for the time being. Once the list is
 * complete, these comments will be removed. They are used only to ensure that
 * the ordering of constants in this file matches the one from the Drupal
 * core.services.yml file.
 *
 * @see core/core.services.yml
 */
final class CoreServices {

  /**
   * The Drupal Cache Context IP service.
   *
   * @see \Drupal\Core\Cache\Context\IpCacheContext
   * @see \Drupal\service_injector\Service\CacheContextIpServiceTrait
   */
  public const CACHE_CONTEXT_IP = 'cache_context.ip';

  /**
   * The Drupal Cache Context Protocol Version service.
   *
   * @see \Drupal\Core\Cache\Context\ProtocolVersionCacheContext
   * @see \Drupal\service_injector\Service\CacheContextProtocolVersionServiceTrait
   */
  public const CACHE_CONTEXT_PROTOCOL_VERSION = 'cache_context.protocol_version';

  /**
   * The Drupal Cache Context Headers service.
   *
   * @see \Drupal\Core\Cache\Context\HeadersCacheContext
   * @see \Drupal\service_injector\Service\CacheContextHeadersServiceTrait
   */
  public const CACHE_CONTEXT_HEADERS = 'cache_context.headers';

  /**
   * The Drupal Cache Context Cookies service.
   *
   * @see \Drupal\Core\Cache\Context\CookiesCacheContext
   * @see \Drupal\service_injector\Service\CacheContextCookiesServiceTrait
   */
  public const CACHE_CONTEXT_COOKIES = 'cache_context.cookies';

  /**
   * The Drupal Cache Context Session service.
   *
   * @see \Drupal\Core\Cache\Context\SessionCacheContext
   * @see \Drupal\service_injector\Service\CacheContextSessionServiceTrait
   */
  public const CACHE_CONTEXT_SESSION = 'cache_context.session';

  /**
   * The Drupal Cache Context Session Exists service.
   *
   * @see \Drupal\Core\Cache\Context\SessionExistsCacheContext
   * @see \Drupal\service_injector\Service\CacheContextSessionExistsServiceTrait
   */
  public const CACHE_CONTEXT_SESSION_EXISTS = 'cache_context.session.exists';

  /**
   * The Drupal Cache Context Request Format service.
   *
   * @see \Drupal\Core\Cache\Context\RequestFormatCacheContext
   * @see \Drupal\service_injector\Service\CacheContextRequestFormatServiceTrait
   */
  public const CACHE_CONTEXT_REQUEST_FORMAT = 'cache_context.request_format';

  /**
   * The Drupal Cache Context URL service.
   *
   * @see \Drupal\Core\Cache\Context\UrlCacheContext
   * @see \Drupal\service_injector\Service\CacheContextUrlServiceTrait
   */
  public const CACHE_CONTEXT_URL = 'cache_context.url';

  /**
   * The Drupal Cache Context URL Site service.
   *
   * @see \Drupal\Core\Cache\Context\SiteCacheContext
   * @see \Drupal\service_injector\Service\CacheContextUrlSiteServiceTrait
   */
  public const CACHE_CONTEXT_URL_SITE = 'cache_context.url.site';

  /**
   * The Drupal Cache Context URL Path service.
   *
   * @see \Drupal\Core\Cache\Context\PathCacheContext
   * @see \Drupal\service_injector\Service\CacheContextUrlPathServiceTrait
   */
  public const CACHE_CONTEXT_URL_PATH = 'cache_context.url.path';

  /**
   * The Drupal Cache Context URL Path Parent service.
   *
   * @see \Drupal\Core\Cache\Context\PathParentCacheContext
   * @see \Drupal\service_injector\Service\CacheContextUrlPathParentServiceTrait
   */
  public const CACHE_CONTEXT_URL_PATH_PARENT = 'cache_context.url.path.parent';

  /**
   * The Drupal Cache Context URL Path Is Front service.
   *
   * @see \Drupal\Core\Cache\Context\IsFrontPathCacheContext
   * @see \Drupal\service_injector\Service\CacheContextUrlPathIsFrontServiceTrait
   */
  public const CACHE_CONTEXT_URL_PATH_IS_FRONT = 'cache_context.url.path.is_front';

  /**
   * The Drupal Cache Context URL Query Args service.
   *
   * @see \Drupal\Core\Cache\Context\QueryArgsCacheContext
   * @see \Drupal\service_injector\Service\CacheContextUrlQueryArgsServiceTrait
   */
  public const CACHE_CONTEXT_URL_QUERY_ARGS = 'cache_context.url.query_args';

  /**
   * The Drupal Cache Context URL Query Args Pagers service.
   *
   * @see \Drupal\Core\Cache\Context\PagersCacheContext
   * @see \Drupal\service_injector\Service\CacheContextUrlQueryArgsPagersServiceTrait
   */
  public const CACHE_CONTEXT_URL_QUERY_ARGS_PAGERS = 'cache_context.url.query_args.pagers';

  /**
   * The Drupal Page Cache Kill Switch service.
   *
   * Line 274.
   *
   * @see \Drupal\Core\PageCache\ResponsePolicy\KillSwitch
   * @see \Drupal\service_injector\Service\PageCacheKillSwitchServiceTrait
   */
  public const PAGE_CACHE_KILL_SWITCH = 'page_cache_kill_switch';

  /**
   * The Drupal Config Factory service.
   *
   * Line 295.
   *
   * @see \Drupal\Core\Config\ConfigFactory
   * @see \Drupal\service_injector\Service\ConfigFactoryServiceTrait
   */
  public const CONFIG_FACTORY = 'config.factory';

  /**
   * The Drupal Serialization JSON service.
   *
   * Line 430.
   *
   * @see \Drupal\Component\Serialization\Json
   * @see \Drupal\service_injector\Service\SerializationJsonServiceTrait
   */
  public const SERIALIZATION_JSON = 'serialization.json';

  /**
   * The Drupal State service.
   *
   * Line 440.
   *
   * @see \Drupal\Core\State\State
   * @see \Drupal\service_injector\Service\StateServiceTrait
   */
  public const STATE = 'state';

  /**
   * The Drupal Path Current service.
   *
   * Line 459.
   *
   * @see \Drupal\Core\Path\CurrentPathStack
   * @see \Drupal\service_injector\Service\PathCurrentServiceTrait
   */
  public const PATH_CURRENT = 'path.current';

  /**
   * The Drupal Module Installer service.
   *
   * Line 508
   *
   * @see \Drupal\Core\Extension\ModuleInstaller
   * @see \Drupal\service_injector\Service\ModuleInstallerServiceTrait
   */
  public const MODULE_INSTALLER = 'module_installer';

  /**
   * The Drupal Entity Type Manager service.
   *
   * Line 553.
   *
   * @see \Drupal\Core\Entity\EntityTypeManager
   * @see \Drupal\service_injector\Service\EntityTypeManagerServiceTrait
   */
  public const ENTITY_TYPE_MANAGER = 'entity_type.manager';

  /**
   * The Symfony Request Stack service.
   *
   * Line 686.
   *
   * @see \Symfony\Component\HttpFoundation\RequestStack
   * @see \Drupal\service_injector\Service\RequestStackServiceTrait
   */
  public const REQUEST_STACK = 'request_stack';

  /**
   * The Drupal Language Manager service.
   *
   * Line 783.
   *
   * @see \Drupal\Core\Language\LanguageManager
   * @see \Drupal\service_injector\Service\LanguageManagerServiceTrait
   */
  public const LANGUAGE_MANAGER = 'language_manager';

  /**
   * The Drupal Path Matcher service.
   *
   * Line 956.
   *
   * @see \Drupal\Core\Path\PathMatcher
   * @see \Drupal\service_injector\Service\PathMatcherServiceTrait
   */
  public const PATH_MATCHER = 'path.matcher';

  /**
   * The Drupal Plugin Manager Mail service.
   *
   * Line 1356.
   *
   * @see \Drupal\Core\Mail\MailManager
   * @see \Drupal\service_injector\Service\PluginManagerMailServiceTrait
   */
  public const PLUGIN_MANAGER_MAIL = 'plugin.manager.mail';

  /**
   * The Drupal Email Validator service.
   *
   * Line 1692.
   *
   * @see \Drupal\Component\Utility\EmailValidator
   * @see \Drupal\service_injector\Service\EmailValidatorServiceTrait
   */
  public const EMAIL_VALIDATOR = 'email.validator';

}
